@@ -16,6 +16,7 @@
 #' @param correl \code{list} correl geom text graphical parameter
 #' @param point \code{list} geom point graphical parameter
 #' @param facets \code{list} facetting graphical parameter
+#' @param covariates list of selected covariates and custom labels, e.g. \code{pmx_cov(values = list("SEX"), labels = list("Sex"))} \code{list} \code{pmxCOVObject} \code{\link{pmx_cov}}
 
 
 #'
@@ -52,7 +53,7 @@
 #' @return ggplot2 object
 #' @example inst/examples/eta_cov.R
 dummy <-
-  function(dname, show.correl, correl, point, facets, filter,
+  function(dname, show.correl, correl, point, facets, covariates, filter,
              strat.facet, strat.color, trans, pmxgpar, labels, axis.title,
              axis.text, ranges, is.smooth, smooth, is.band, band, is.draft,
              draft, is.identity_line, identity_line, scale_x_log10,
@@ -67,6 +68,7 @@ dummy <-
 
 #' Relationships between (ETA) and categorical covariates
 #' @family eta_cov_plot
+#' @return ggplot2 object
 #' @rdname eta_cov_plot
 #' @export
 
@@ -81,6 +83,7 @@ pmx_plot_eta_cats <-
 
 #' Relationships between (ETA) and continuous covariates
 #' @family eta_cov_plot
+#' @return ggplot2 object
 #' @rdname eta_cov_plot
 #' @export
 pmx_plot_eta_conts <-
