@@ -19,9 +19,9 @@ ctr %>% pmx_plot_eta_qq(reference_line=NULL)
 # stratification  ----------------------------------
 
 ## categorical stratification color parameter
-ctr %>% pmx_plot_iwres_qq(strat.facet="STUD",strat.color="SEX")
+ctr %>% pmx_plot_iwres_qq(strat.facet=~STUD,strat.color="SEX")
 ## categorical stratification facetting
-ctr %>% pmx_plot_eta_qq(strat.facet = "SEX")
+ctr %>% pmx_plot_eta_qq(strat.facet = ~SEX)
 
 ## do not use symmetric axis
 ctr %>% pmx_plot_npde_qq(xmax=FALSE,reference_line=list())
