@@ -2,11 +2,21 @@ if (helper_skip()) {
 
   context("Test config")
 
+  # check return value of print(x) without writing output to console
+  print_return_value <- function(x) {
+    tmp <- capture.output(y <- print(x))
+    y
+  }
+  
   #-------------pmx_config START --------------------------------------------
   test_that("pmx_config params: inputs result: error", {
     input_dir <-
       file.path(system.file(package = "ggPMX"), "templates", "mlx")
-    expect_error(pmx_config(inputs = input_dir))
+    expect_error(
+      suppressWarnings(
+        pmx_config(inputs = input_dir)
+      )
+    )
   })
 
   test_that("pmx_config params: plots, inputs result: identical inherits", {
@@ -280,14 +290,19 @@ if (helper_skip()) {
 
 
   test_that("print.pmxConfig : x; result: identical structure", {
-    pr <- print.pmxConfig(config)
+    ignore <- capture.output({
+      pr <- print.pmxConfig(config)
+    })
+    pr <- print_return_value(config)
     expect_identical("mlx", pr$sys)
     expect_true(exists("plots", pr))
     expect_true(exists("data", pr))
   })
 
   test_that("print.pmxConfig : x; result: identical names", {
-    pr <- print.pmxConfig(config)
+    ignore <- capture.output({
+      pr <- print.pmxConfig(config)
+    })
     prNames <- c("data", "plots", "sys", "hasNpd")
     expect_identical(prNames, names(pr))
 
@@ -296,22 +311,23 @@ if (helper_skip()) {
       "IWRES_QQ", "NPDE_TIME", "NPDE_PRED", "NPDE_QQ",
       "DV_PRED", "DV_IPRED", "INDIVIDUAL", "ETA_HIST",
       "ETA_BOX", "ETA_MATRIX", "ETA_CATS", "ETA_CONTS", "ABS_IWRES_TIME",
-      "ETA_QQ", "PMX_VPC"
+      "ETA_QQ", "PMX_VPC", "SAEM_CONVERGENCE"
     )
-    print(setdiff(names(pr$plots), plotNames))
-    dataNames <- c("predictions", "estimates", "eta", "finegrid")
+
+    dataNames <- c("predictions", "estimates", "eta", "finegrid", "saem")
     expect_setequal(plotNames, names(pr$plots))
     expect_setequal(dataNames, names(pr$data))
   })
 
 
   test_that("print.pmxConfig : x; result: identical inherits", {
-    pr <- print.pmxConfig(config)
+    ignore <- capture.output({
+      pr <- print.pmxConfig(config)
+    })
     expect_true(inherits(pr, "pmxConfig"))
   })
 
   #-------------print.pmxConfig END ----------------------------------------------
-
   #-------------load_config_files START ------------------------------------------
 
   test_that("load_config_files : ifile, pfile, sys; result: identical inherits", {
