@@ -3,7 +3,6 @@ if (helper_skip()) {
   tmp_dir <- tempfile("tmp")
   dir.create(tmp_dir)
 
-
   test_that("merge vectors error works", {
     expect_error(
       mergeVectors.(1:4, 5:8),
@@ -13,13 +12,13 @@ if (helper_skip()) {
 
 
   test_that("pk_pd is working", {
-    ctr <- pk_pd()
+    tmp <- capture.output(ctr <- pk_pd()) # assign ctr silently
     expect_s3_class(ctr, "pmxClass")
   })
 
 
   test_that("pk_pd params: code; result: identical structure", {
-    ctr <- pk_pd(code = "4")
+    tmp <- capture.output(ctr <- pk_pd(code = "4")) # assign ctr silently
     pk_pd_path <- file.path(
       system.file(package = "ggPMX"), "testdata",
       "pk_pd"
@@ -85,10 +84,17 @@ if (helper_skip()) {
     wd,
     "project.mlxtran"
   )
-
+  
+  test_that("parse_mlxtran: params: no warning", {
+    skip("skipping ChartsData export warning test")
+    expect_no_warning(
+      parse_mlxtran(file_name), 
+      message = "ggPMX needs ChartsData exported"
+    )
+  })
 
   test_that("parse_mlxtran: params: folder name", {
-    a <- parse_mlxtran(file_name)
+    a <- suppressWarnings(parse_mlxtran(file_name))
     expect_true(inherits(
       a,
       "list"
@@ -111,7 +117,7 @@ if (helper_skip()) {
     lines[grepl("exportpath = ", lines) == TRUE] <- paste0("exportpath = '", wd, "/result'")
 
     writeLines(lines, mlxpath)
-    a <- parse_mlxtran(mlxpath)
+    a <- suppressWarnings(parse_mlxtran(mlxpath))
     file.remove(mlxpath)
     unlink(file.path(wd, "result"), recursive = TRUE)
 
@@ -119,7 +125,12 @@ if (helper_skip()) {
       a,
       "list"
     ))
-    expect_equal(normalizePath(a$directory), normalizePath(file.path(wd, "result")))
+    
+    # for test purposes doesn't matter if files don't exist
+    path_1 <- suppressWarnings(normalizePath(a$directory))
+    path_2 <- suppressWarnings(normalizePath(file.path(wd, "result")))
+    
+    expect_equal(path_1, path_2)
   })
 
 
@@ -136,7 +147,7 @@ if (helper_skip()) {
     lines[grepl("exportpath = ", lines) == TRUE] <- paste0("exportpath = '", wd, "/result/res'")
 
     writeLines(lines, mlxpath)
-    a <- parse_mlxtran(mlxpath)
+    a <- suppressWarnings(parse_mlxtran(mlxpath))
     file.remove(mlxpath)
     unlink(file.path(wd, "result"), recursive = TRUE)
 
@@ -199,7 +210,7 @@ if (helper_skip()) {
 
   test_that("parse_mlxtran params: file_name result: identical names", {
     mlxtran_path <- file.path(system.file(package = "ggPMX"), "testdata", "1_popPK_model", "project.mlxtran")
-    par <- parse_mlxtran(file_name = mlxtran_path)
+    par <- suppressWarnings(parse_mlxtran(file_name = mlxtran_path))
     parseNames <- c("directory", "input", "dv", "id", "time", "cats", "conts", "occ", "dvid", "endpoint")
     expect_identical(names(par), parseNames)
   })
@@ -207,14 +218,14 @@ if (helper_skip()) {
 
   test_that("parse_mlxtran params: file_name result: identical inherits", {
     mlxtran_path <- file.path(system.file(package = "ggPMX"), "testdata", "1_popPK_model", "project.mlxtran")
-    par <- parse_mlxtran(file_name = mlxtran_path)
+    par <- suppressWarnings(parse_mlxtran(file_name = mlxtran_path))
     expect_true(inherits(par, "list"))
   })
 
 
   test_that("parse_mlxtran params: file_name result: identical structure", {
     mlxtran_path <- file.path(system.file(package = "ggPMX"), "testdata", "1_popPK_model", "project.mlxtran")
-    par <- parse_mlxtran(file_name = mlxtran_path)
+    par <- suppressWarnings(parse_mlxtran(file_name = mlxtran_path))
     expect_identical(par$cats, c("SEX", "RACE", "DISE", "ILOW"))
     expect_identical(par$endpoint$code, "1")
     expect_identical(par$time, "TIME")
